@@ -275,7 +275,7 @@ def render_table(data, append_headers, append_lineno):
     append_headers(data, html)
 
     for i, row in enumerate(data["rows"]):
-        trow = ["<tr>"]
+        trow = [('<tr id="{}">').format(i)]
         append_lineno(trow, i)
         for cell in row:
             if cell["column"] in hidden_columns:
@@ -294,7 +294,6 @@ def render_table(data, append_headers, append_lineno):
             trow.append(
                 (
                     '<td {attrs_str} style="{styles_str}">'
-                    "{i}"
                     "{formatted_images}"
                     "{formatted_value}"
                     "</td>"
